<?php

switch ($messaggio) {

case "Vedi le prenotazioni":  			$messaggio = "Посмотреть брони"; break;
case "presenti dal":  				$messaggio = "присутствующие от"; break;
case "al":  					$messaggio = "_"; break;
case "Senza colori":  				$messaggio = "Без цвета"; break;
case "Con colori":  				$messaggio = "С цветом"; break;
case "Tabella prenotazioni precedenti al":  	$messaggio = "Таблица с бронями, ранее чем"; break;
case "Tabella prenotazioni successive al":  	$messaggio = "Таблица с бронями последующими"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Таблица со всеми бронями"; break;
case "Cognome_cliente":  			$messaggio = "Фамилия_клиента"; break;
case "Data_iniziale":  				$messaggio = "Дата_начала"; break;
case "Data_finale":  				$messaggio = "Дата_окончания"; break;
case "sett":  					$messaggio = "W"; break;
case "gio":  					$messaggio = "D"; break;
case "Tariffa_completa":  			$messaggio = "Полный_тариф"; break;
case "Caparra":  				$messaggio = "Депозит"; break;
case "Pagato":  				$messaggio = "Оплачен"; break;
case "Da_pagare":  				$messaggio = "Для_оплаты"; break;
case "Pers.":  					$messaggio = "Люди"; break;
case "Commento":  				$messaggio = "Комментарий"; break;
case "Costo_uni.":  				$messaggio = "Единичная_стоимость"; break;
case "Costo_sett.":  				$messaggio = "Еженедельная_стоимость"; break;
case "Costo_gio.":  				$messaggio = "Ежедневная_стоимость"; break;
case "Soldi di prenotazioni cancellate":  	$messaggio = "Деньги удаленных броней"; break;
case "TOTALE":  				$messaggio = "ИТОГ"; break;
case "Trasferito in cassa":  			$messaggio = "Перенесено в наличные"; break;
case "RESTO":  					$messaggio = "ОСТАТОК"; break;
case "Sei sicuro di voler cancellare la spesa":	$messaggio = "Вы уверены, что хотите удалить оплату наличными"; break;
case "del valore di":  				$messaggio = "от"; break;
case "Sei sicuro di voler cancellare l'entrata":	$messaggio = "Вы уверены, что хотите удалить наличную квитанцию"; break;
case "SI":  					$messaggio = "ДА"; break;
case "NO":  					$messaggio = "НЕТ"; break;
case "Entrata o spesa":  			$messaggio = "Оплата наличными или квитанция"; break;
case "cacellata":  				$messaggio = "удалена"; break;
case "Costo o spesa già cancellati":  		$messaggio = "Cash payment or receipt already deleted"; break;
case "Natura_spesa":  				$messaggio = "Основание_для_оплаты"; break;
case "Importo":  				$messaggio = "Значение"; break;
case "Inserita_da":  				$messaggio = "Вставлена"; break;
case "Data_di_inserimento":  			$messaggio = "Дата_добавления"; break;
case "Cancella":  				$messaggio = "Удалить"; break;
case "Natura_entrata":  			$messaggio = "Основание_для_квитанции"; break;
case "cancella":  				$messaggio = "удалить"; break;
case "entrata presa dalle prenotazioni":  	$messaggio = "Наличная квитанция взята из броней"; break;
case "Inserisci nuove spese o entrate":  	$messaggio = "Добавить новые наличные выручки или платежи"; break;
case "Storia entrate-uscite prenotazioni":  	$messaggio = "История платежей броней"; break;
case "Sei sicuro di voler cancellare il costo aggiuntivo":	$messaggio = "Вы уверены, что хотите удалить дополнительные расходы"; break;
case "Il costo aggiuntivo":  			$messaggio = "Дополнительные расходы"; break;
case "Il costo aggiuntivo è cambiato nel frattempo, non è stato cancellato":	$messaggio = "Дополнительные расходы были изменены тем временем, они не были удалены"; break;
case "è stato cancellato":  			$messaggio = "были удалены"; break;
case "I periodi sono stati aggiunti fino al":  	$messaggio = "Периоды были добавлены до"; break;
case "Tabella con periodi e relative tariffe del":	$messaggio = "Таблица с периодами и соответствующие тарифами от"; break;
case "tariffa":  				$messaggio = "тариф"; break;
case "Inizio_settimana":  			$messaggio = "Неделя_начала"; break;
case "Inizio_giorno":  				$messaggio = "День_начала"; break;
case "Fine_settimana":  			$messaggio = "Неделя_окончания"; break;
case "Fine_giorno":  				$messaggio = "День_окончания"; break;
case "Aggiungi periodi":  			$messaggio = "Добавить периоды"; break;
case "fino al mese":  				$messaggio = "до месяца"; break;
case "Tabella con i costi aggiuntivi del":  	$messaggio = "Таблица с дополнительными расходами"; break;
case "Nome":  					$messaggio = "Имя"; break;
case "Tipo":  					$messaggio = "Тип"; break;
case "Prezzo":  				$messaggio = "Значение"; break;
case "Da_assegnare":  				$messaggio = "Для_присвоения"; break;
case "finale":  				$messaggio = "единичный"; break;
case "Sempre":  				$messaggio = "Всегда"; break;
case "Su_richiesta":  				$messaggio = "По_запросу"; break;
case "chidere_per_quanto_moltiplicare":  	$messaggio = "спросить_на_сколько_умножить"; break;
case "cosiderare_come_letti_aggiuntivi":  	$messaggio = "рассматривать_как_дополнительные_места"; break;
case "settimanale":  				$messaggio = "еженедельно"; break;
case "giornaliero":  				$messaggio = "ежедневно"; break;
case "tutte":  				$messaggio = "весь"; break;
case "tutti":  				$messaggio = "все"; break;
case "_le":  					$messaggio = "_этот"; break;
case "_i":  					$messaggio = "_эти"; break;
case "_settimane":  				$messaggio = "_недели"; break;
case "_giorni":  				$messaggio = "_дни"; break;
case "_meno_una":  				$messaggio = "_минус_один"; break;
case "con_n°_di_settimane":  			$messaggio = "спрашивая_число_недель"; break;
case "con_n°_di_giorni":  			$messaggio = "спрашивая_число_дней"; break;
case "_da_chiedere":  				$messaggio = ""; break;
case "percentuale":  				$messaggio = "процент"; break;
case "% arrotondato_a_":  			$messaggio = "% округляя_к_"; break;
case "Vai alla pagina di inserzione prezzi":  	$messaggio = "Перейти к странице вставки прайсов"; break;
case "chiamati":  				$messaggio = "названный"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Таблица со всеми клиентами"; break;
case "pag. prec.":  				$messaggio = "предыдущая страница"; break;
case "pag. succ.":  				$messaggio = "следующая страница"; break;
case "Cognome":  				$messaggio = "Фамилия"; break;
case "Nome":  					$messaggio = "Имя"; break;
case "Telefono":  				$messaggio = "Телефон"; break;
case "Indirizzo":  				$messaggio = "Адрес"; break;
case "Città":  					$messaggio = "Город"; break;
case "Nazione":  				$messaggio = "Страна"; break;
case "CAP":  					$messaggio = "Почтовый индекс"; break;
case "Fax":  					$messaggio = "Факс"; break;
case "Email":  					$messaggio = "E-mail"; break;
case "Data_di_nascita":  			$messaggio = "День рождения"; break;
case "2°telefono":  				$messaggio = "2-й телефон"; break;
case "Commento":  				$messaggio = "Комментарий"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "Вы уверены, что хотите <b>удалить</b> правило размещения 2 для"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Вы уверены, что хотите <b>удалить</b> правило размещения 3 для"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Вы уверены, что хотите <b>удалить</b> правило размещения 4 для"; break;
case "La regola di assegnazione è stata cancellata":	$messaggio = "Правило размещения было удалено"; break;
case "del":  					$messaggio = "от"; break;
case "Motivazione":  				$messaggio = "Причина"; break;
case "Tariffa":  				$messaggio = "Тариф"; break;
case "Inserisci nuove regole":  		$messaggio = "Добавить новые правила"; break;
case "Il numero inserito esiste già":  		$messaggio = "Вставленный номер уже существует"; break;
case "Continua":  				$messaggio = "Продолжить"; break;
case "Torna indietro":  			$messaggio = "Идите назад"; break;
case "Casa":  					$messaggio = "Корпус"; break;
case "Piano":  					$messaggio = "Этаж"; break;
case "Capienza_massima":  			$messaggio = "Максимум_совместимости"; break;
case "Priorità":  				$messaggio = "Приоритет"; break;
case "Modifica":  				$messaggio = "Изменить"; break;
case "modifica":  				$messaggio = "изменить"; break;
case "Torna al menù principale":  		$messaggio = "Назад к главному меню"; break;
case "persone":  				$messaggio = "человек(а)"; break;
case "s":  					$messaggio = "w"; break;
case "g":  					$messaggio = "d"; break;
case "Mostra":  				$messaggio = "Показать"; break;
case "Non_mostrare":  				$messaggio = "Не_показывать"; break;
case "Regole":  				$messaggio = "Правила"; break;
case "Tariffe abbinate":  			$messaggio = "Привязанные тарифы"; break;
case "pagine":  				$messaggio = "страницы"; break;
case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "Вы сделаете эти изменения"; break;
case "I soldi pagati per la prenotazione":  	$messaggio = "Деньги, заплаченные за бронь"; break;
case "a nome di":  				$messaggio = "для Г-на/Г-жи"; break;
case "verranno cambiati da":  			$messaggio = "будет изменен с"; break;
case "a":  					$messaggio = "на"; break;
case "saldo":  					$messaggio = "разница"; break;
case "Le prenotazioni <b>non sono state modificate</b> perchè sono cambiate nel frattempo":	$messaggio = "Брони <b>не изменены</b>, потому что таблица броней изменилась тем временем"; break;
case "tutto pagato":  				$messaggio = "все оплачено"; break;
case "caparra pagata":  			$messaggio = "депозит оплачен"; break;
case "pagato niente":  				$messaggio = "ничего не оплачено"; break;
case "pagina":  				$messaggio = "страница"; break;
case "di":  					$messaggio = "от"; break;
case "la conferma":  				$messaggio = "подтверждена"; break;
case "La prenotazione":  			$messaggio = "Бронь"; break;
case "Data di inserimento":  			$messaggio = "Дата добавления"; break;
case "Calcola il subtotale delle prenotazioni selezionate":	$messaggio = "Вычислить промежуточный итог отобранных броней"; break;
case "selezionate precedentemente":  		$messaggio = "заранее выбранные"; break;
case "Saldo totale":  				$messaggio = "Полная разница"; break;
case "l'anno":  				$messaggio = "год"; break;
case "dal database":  				$messaggio = "из базы данных"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, tutti i dati riguardanti l'anno":	$messaggio = "<b style=\"color: red;\">ПРЕДУПРЕЖДЕНИЕ</b>: если вы нажмете <b>\"<i>Продолжить</i>\"</b>, все данные относящиеся к году"; break;
case "verranno <b>cancellati</b>":  		$messaggio = "будут <b>удалены</b>"; break;
case "L'anno":  				$messaggio = "Год"; break;
case "è stato cancellato dal batabase":  	$messaggio = "был удален из базы данных"; break;
case "Non è stato possibile cancellare l'anno":	$messaggio = "Невозможно было удалить год"; break;
case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "из базы данных, проверьте разрешения на папку dati"; break;
case "Profilo":  				$messaggio = "Профиль"; break;
case "Cliente":  				$messaggio = "Клиент"; break;
case "cliente":  				$messaggio = "клиент"; break;
case "Utente":  				$messaggio = "Пользователь"; break;
case "Periodi_permessi":  			$messaggio = "Разрешенные_периоды"; break;
case "unico":  					$messaggio = "единичный"; break;
case "fisso":  					$messaggio = "исправлен"; break;
case "percentuale su tariffa":  		$messaggio = "процент тарифа"; break;
case "percentuale su totale":  			$messaggio = "процент от полного"; break;
case "varia_con_la_prenotazione":  		$messaggio = "изменить_в_брони"; break;
case "non_varia_con_la_prenotazione":  		$messaggio = "не_изменять_бронь"; break;
case "_meno_l'ultima":  			$messaggio = "_кроме_последнего"; break;
case "_meno_l'ultimo":  			$messaggio = "_кроме_последних"; break;
case "_meno_la_prima":  			$messaggio = "_кроме_первого"; break;
case "_meno_il_primo":  			$messaggio = "_кроме_первых"; break;
case "giorni":  				$messaggio = "дни"; break;
case "moltiplicare_per_persone":  		$messaggio = "умножено_на_людей"; break;
case "moltiplicare_per_persone_totali":  	$messaggio = "умножено_на_полное_количество_людей"; break;
case "moltiplicare_per_1":  			$messaggio = "умножено_на_одного"; break;
case "massimo_":  				$messaggio = "максимум_"; break;
case "_nella_stessa_settimana":  		$messaggio = "_в_ту_же_неделю"; break;
case "_nello_stesso_giorno":  			$messaggio = "_в_тот_же_день"; break;
case "Prenotazione intera in":  		$messaggio = "Полная бронь в"; break;
case "Parte della prentoazione in":  		$messaggio = "Часть брони в"; break;
case "Solo settimane della prenotazione in":  	$messaggio = "Только недели от брони в"; break;
case "Solo giorni della prenotazione in":  	$messaggio = "Только дни оговорки в"; break;
case " o ":  					$messaggio = " или "; break;
case " a ":  					$messaggio = "  в"; break;
case "_si":  					$messaggio = "_да"; break;
case "_no":  					$messaggio = "_нет"; break;
case "_e_":  					$messaggio = "_и_"; break;
case "associato_a_settimane_specifiche":  	$messaggio = "связано_с_определенными_неделями"; break;
case "non_associato_a_settimane_specifiche":  	$messaggio = "не_связано_с_определенными_неделями"; break;
case "associato_a_giorni_specifici":  		$messaggio = "связано_с_определенными_датами"; break;
case "non_associato_a_giorni_specifici":  	$messaggio = "не_связано_с_определенными_датами"; break;
case "modifica con prenotazione":  		$messaggio = "измените с оговоркой"; break;
case "percentuale su caparra":  		$messaggio = "процент депозита"; break;
case "percentuale su resto caparra":  		$messaggio = "процент разницы депозита"; break;
case "Cancellati":  				$messaggio = "Удален"; break;
case "clienti":  				$messaggio = "клиенты"; break;
case "OK":  					$messaggio = "OK"; break;
case "Annulla":  				$messaggio = "Отмена"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":	$messaggio = "Вы уверены, что хотите <div style=\"display: inline; color: red;\"><b>удалить"; break;
case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":	$messaggio = "клиентов</b></div>, которые не имеют никакой привязанных к ним броней или оплат"; break;
case "Cancella i clienti senza prenotazioni":	$messaggio = "Удалить клиентов без броней"; break;
case "Metodo pagamento":  			$messaggio = "Метод оплаты"; break;
case "del":  					$messaggio = "of"; break;
case "Modifica tutti i campi della tabella":  	$messaggio = "Изменить все поля таблицы"; break;
case "Modifica i campi della tabella":  	$messaggio = "Изменить поля таблицы"; break;
case "Applica i cambiamenti":  			$messaggio = "Примените изменения"; break;
case "Vedi tutte le prenotazioni":  		$messaggio = "Посмотреть все брони"; break;
case "Numero di persone":  			$messaggio = "Число людей"; break;
case "assegna_se_":  				$messaggio = "присвоено_если_"; break;
case "più_di_":  				$messaggio = "менее_чем_"; break;
case "meno_di_":  				$messaggio = "более_чем_"; break;
case "_giorni_da_inizio":  			$messaggio = "_дни_от_начала"; break;
case "assegna_con_":  				$messaggio = "присвоить_с_"; break;
case "_o_più_prenotazioni":  			$messaggio = "_или_более_броней"; break;
case "Modifica i prezzi":  			$messaggio = "Изменить прайсы"; break;
case "I prezzi sono stati aggiornati":  	$messaggio = "Прайсы были обновлены"; break;
case "Tutte le prenotazioni":  			$messaggio = "Все брони"; break;
case "Solo arrivi":  				$messaggio = "Только прибывающие"; break;
case "Solo partenze":  				$messaggio = "Только отъезжающие"; break;
case "dal":  					$messaggio = "из"; break;
case "Vedi":  					$messaggio = "Посмотреть"; break;
case "Tabella con tutti gli arrivi":  		$messaggio = "Таблица со всеми прибывающими"; break;
case "Tabella con tutte le partenze":  		$messaggio = "Таблица со всеми отъезжающими"; break;
case "prova ad importare i prezzi":  		$messaggio = "попытаться импортировать прайсы"; break;
case "giornalmente":  				$messaggio = "дневные"; break;
case "settimanalmente":  			$messaggio = "недельные"; break;
case "Origine":  				$messaggio = "Источник"; break;
case "aggiungi":  				$messaggio = "add"; break;
case "Beni inventario":  			$messaggio = "Inventory goods"; break;
case "in":  					$messaggio = "in"; break;
case "giorno":  				$messaggio = "day"; break;
case "p":  					$messaggio = "p"; break;
case "Aggiungi":  				$messaggio = "Add"; break;
case "e":  					$messaggio = "and"; break;
case "Id":  					$messaggio = "Id"; break;
case "chiedere":  				$messaggio = "ask"; break;
case "Visualizza Tabelle":  			$messaggio = "View Tables"; break;
case "Tutte le spese del":  			$messaggio = "All expenses of"; break;
case "nella cassa principale":  		$messaggio = "in main cashbox"; break;
case "Tutte le entrate del":  			$messaggio = "All incomes of"; break;
case "Caparre, commissioni e tasse del":  	$messaggio = "Deposits, commissions and taxes of"; break;
case "Arrotondato_a":  				$messaggio = "Rounded_to"; break;
case "Cerca i clienti con cognome o email":  	$messaggio = "Search clients with surname or email"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 1 for"; break;
case "La regola di assegnazione è già stata cancellata":	$messaggio = "The assignment rule has already been deleted"; break;
case "Tabella con le regole di assegnazione":	$messaggio = "Table with the assignment rules"; break;
case "porre per le prenotazioni selezionate":  	$messaggio = "selected reservations to"; break;
case "cambia":  				$messaggio = "change"; break;
case "verrà confermata":  			$messaggio = "will be confirmed"; break;
case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
case "Tariffe":  				$messaggio = "Rates"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "<div style=\"display: inline; color: red;\">Non</div> è stato possibile inserire alcuni prezzi":	$messaggio = "It was <div style=\"display: inline; color: red;\">not</div> possible to insert some prices"; break;
case "Modifica come gruppo le prenotazioni mostrate in tabella":	$messaggio = "Modify reservations shown in table as a group"; break;
case "Modifica come gruppo le prenotazioni selezionate":	$messaggio = "Modify selected reservations as a group"; break;
case "Statistiche":  				$messaggio = "Statistics"; break;
case "Anni":  					$messaggio = "Years"; break;
case "Numero di prenotazioni per mese":  	$messaggio = "Number of reservations per month"; break;
case "Entrate dalle prenotazioni per mese":  	$messaggio = "Incomes from reservations per month"; break;
case "Entrate progressive dalle prenotazioni":	$messaggio = "Progressive incomes from reservations"; break;
case "Numero di prenotazioni per origine":  	$messaggio = "Number of reservations per origin"; break;
case "Entrate dalle prenotazioni per origine":	$messaggio = "Incomes from reservations per origin"; break;
case "Cambia":  				$messaggio = "Change"; break;
case "Mesi":  					$messaggio = "Months"; break;
case "Entrate per metodo di pagamento":  	$messaggio = "Incomes per payment method"; break;
case "Descrizione":  				$messaggio = "Description"; break;
case "magazzino":  				$messaggio = "stockroom"; break;
case "inventario":  				$messaggio = "inventory"; break;
case "Codice":  				$messaggio = "Code"; break;
case "Mancanti":  				$messaggio = "Missing"; break;
case "bene eliminato":  			$messaggio = "item deleted"; break;
case "bene aggiunto":  				$messaggio = "item added"; break;
case "magazzino eliminato":  			$messaggio = "stockroom deleted"; break;
case "magazzino aggiunto":  			$messaggio = "stockroom added"; break;
case "Inventario importato":  			$messaggio = "Inventory imported"; break;
case "Importa l'invetario":  			$messaggio = "Import inventory"; break;
case "dal magazzino":  				$messaggio = "from stockroom"; break;
case "Incompatibilità":  			$messaggio = "Incompatibilities"; break;
case "raggruppa":  				$messaggio = "group"; break;
case "con email":  				$messaggio = "with email"; break;
case "Importa":  				$messaggio = "Import"; break;
case "per persona":  				$messaggio = "per person"; break;
case "con meno di":  				$messaggio = "with less than"; break;
case "dall'inizio":  				$messaggio = "from beginning"; break;
case "dalla fine":  				$messaggio = "from ending"; break;
case "Mostra solo tariffe selezionate":  	$messaggio = "Show only selected rates"; break;
case "mostra prezzi settimanali":  		$messaggio = "show weekly prices"; break;
case "mostra prezzi giornalieri":  		$messaggio = "show daily prices"; break;
case "periodi di":  				$messaggio = "periods of"; break;
case "Valore":  				$messaggio = "Value"; break;
case "della tariffa":  				$messaggio = "of rate"; break;
case "piano":  					$messaggio = "floor"; break;
case "casa":  					$messaggio = "house"; break;
case "documento":  				$messaggio = "document"; break;
case "documenti salvati":  			$messaggio = "saved documents"; break;
case "numero":  				$messaggio = "number"; break;
case "nome file":  				$messaggio = "filename"; break;
case "prenotazioni":  				$messaggio = "reservations"; break;
case "azione":  				$messaggio = "action"; break;
case "anno":  					$messaggio = "year"; break;
case "elimina":  				$messaggio = "delete"; break;
case "fai l'upload del documento numero":  	$messaggio = "upload document number"; break;
case "fai l'upload":  				$messaggio = "upload"; break;
case "si è sicuri di voler <b class=\"colred\">cancellare</b> il documento":	$messaggio = "Are you sure you want to <b class=\"colred\">delete</b> document"; break;
case "cancellato":  				$messaggio = "deleted"; break;
case "inviato":  				$messaggio = "uploaded"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Tasse":  					$messaggio = "Taxes"; break;
case "senza_commissioni":  			$messaggio = "without_commissions"; break;
case "Documenti_salvati":  			$messaggio = "Saved_documents"; break;
case "TASSE":  					$messaggio = "TAXES"; break;
case "resto":  					$messaggio = "rest"; break;
case "cancella_periodi":  			$messaggio = "delete_periods"; break;
case "Sei sicuro di voler cancellare le commissioni dal":	$messaggio = "Are you sure you want to delete commissions from"; break;
case "sulla tariffa":  				$messaggio = "on rate"; break;
case "Le commissioni sono state cancellate":  	$messaggio = "Commissions have been deleted"; break;
case "Le commissioni sono cambiate nel frattempo, non sono state cancellate":	$messaggio = "Commissions have changed meanwhile, they have not been deleted"; break;
case "settimana":  				$messaggio = "week"; break;
case "costi agg.":  				$messaggio = "extra costs"; break;
case "sconto":  				$messaggio = "discount"; break;
case "Numero di prenotazioni per nazionalità del cliente titolare":	$messaggio = "Number of reservations per nationality of titular client"; break;
case "Entrate dalle prenotazioni per nazionalità del cliente titolare":	$messaggio = "Incomes from reservations per nationality of titular client"; break;
case "Prezzi con":  				$messaggio = "Prices with"; break;
case "Prenotazioni anno corrente":  		$messaggio = "Current year reservations"; break;
case "con prenotazioni inserite":  		$messaggio = "with reservations inserted"; break;
case "fino al":  				$messaggio = "until"; break;
case "nella cassa chiamata":  			$messaggio = "in the cashbox called"; break;
case "Totale nella cassa principale":  		$messaggio = "Total in main cashbox"; break;
case "Totale nella cassa":  			$messaggio = "Total in cashbox"; break;
case "Nuova cassa chiamata":  			$messaggio = "New cashbox called"; break;
case "Crea":  					$messaggio = "Create it"; break;
case "Una cassa chiamata":  			$messaggio = "A cashbox called"; break;
case "è stata creata":  			$messaggio = "has been created"; break;
case "Cassa chiamata":  			$messaggio = "Cashbox called"; break;
case "La cassa chiamata":  			$messaggio = "The cashbox called"; break;
case "è stata cancellata":  			$messaggio = "has been deleted"; break;
case "Eventuali entrate e spese presenti in cassa non sono state cancellate":	$messaggio = "Any incomes and expenses present in this cashbox have not been deleted"; break;
case "Modifica i beni già inseriti":  		$messaggio = "Modify already inserted items"; break;
case "Modifica i beni":  			$messaggio = "Modify items"; break;
case "I beni sono stati modificati":  		$messaggio = "The items have been modified"; break;
case "e combina":  				$messaggio = "and combine"; break;
case "percentuale su fisso della tariffa":	$messaggio = "percentage of fixed rate"; break;
case "percentuale su una persona della tariffa":	$messaggio = "percentage of one person of the rate"; break;
case "non più di":  				$messaggio = "no more than"; break;
case "non più del numero di persone":  		$messaggio = "no more than the number of people"; break;
case "non più del numero totale di persone":  	$messaggio = "no more than the total number of people"; break;
case "meno":  					$messaggio = "minus"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "più di":  				$messaggio = "more than"; break;
case "prezzi importati":  			$messaggio = "prices imported"; break;
case "dalla tariffa":  				$messaggio = "from rate"; break;
case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Delete credit cards of past reservations"; break;
case "password per le carte di credito":  	$messaggio = "password for credit cards"; break;
case "Cancellate":  				$messaggio = "Deleted"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "Creare":  				$messaggio = "Create"; break;
case "persona":  				$messaggio = "person"; break;
case "chiusa":  				$messaggio = "closed"; break;
case "presenti in data":  			$messaggio = "present on"; break;
case "comprese partenze":  			$messaggio = "including departures"; break;
case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_total"; break;
case "da varie tariffe":  			$messaggio = "from different<br>rates"; break;
case "senza letti aggiuntivi":  		$messaggio = "without extra beds"; break;
case "Premere per modificare":  		$messaggio = "Click to modify"; break;
case "Converti definitivamente in":  		$messaggio = "Permanently convert into"; break;
case "al cambio attuale":  			$messaggio = "at current exchange rate"; break;
case "Le altre valute presenti nella cassa":  	$messaggio = "Other currencies in cashbox"; break;
case "sono state convertite in":  		$messaggio = "have been converted into"; break;
case "Tabella con le prenotazioni cancellate":	$messaggio = "Table with deleted reservations"; break;
case "<b>non importare</b> i prezzi":  		$messaggio = "<b>do not import</b> prices"; break;
case "Attenzione":  				$messaggio = "Notice"; break;
case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "periods added now can't be deleted later"; break;
case "come tipo di persona":  			$messaggio = "as person type"; break;
case "e applica la % del tipo di persona":  	$messaggio = "and apply the % of person type"; break;
case "escludendo":  				$messaggio = "excluding"; break;
case "includendo solo":  			$messaggio = "including only"; break;
case "Superato il massimo numero di anni comparabili":	$messaggio = "Exceeded the maximum number of comparable years"; break;
case "Numero_predefinito di persone":  		$messaggio = "Default_number of people"; break;
case "Numero_minimo di persone":  		$messaggio = "Minimum_number of people"; break;
case "Cancellare anche":  			$messaggio = "Delete also"; break;
case "clienti con solo prenotazioni cancellate negli anni passati, cancellando le loro prenotazioni in modo permanente":	$messaggio = "clients with only deleted reservations in past years, deleting their reservations permanently"; break;
case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
case "Anche cancellate":  			$messaggio = "Also deleted"; break;
case "Solo cancellate":  			$messaggio = "Only deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
